#!/usr/bin/perl
#
# areatable.pl - v0.2 
# Createing an conference area table in an SQL (Mysql) based database.
#  Copyright (c) 2001-2004,2010 Robert James Clay.  All Rights Reserved.
#  This is free software;  you can redistribute it and/or
#  modify it under the same terms as Perl itself.

# note that the description option does not work for more than the first word...
# use some other way of initially putting description in?

use warnings;
use strict;
use Getopt::Std;
use vars qw/ $opt_a $opt_b $opt_l $opt_t $opt_d $opt_f $opt_h $opt_v $opt_x /;

my ($area, $bbsname, $desc, $type, $domain, $db_handle, $sql_statement, $log_file, $Debug);
 
#print @INC"\n";

getopts('a:b:t:f:d:l:vxh');

if($opt_h) {
    print "\nUsage: areatable.pl -a echoname -b bbsname [-t L|N|C] [-l logfile] [-d domain] [-f description_file] [-x]\n";
    print "echoname = areaname as distributed...\n";
    print "bbsname = name of echoarea to be added to bbs, defaults to same as echoname..\n";
    print "type = L=local, N=netmail, C=Conference. defaults to C\n";
    print "[-d domain] = if not present, domain defaults to table default (fidonet). \n\n";
    print "[-f description_file] = if not present, echo description defaults to name of echo. \n\n";
    print "[-x] if present, debug mode is set...\n";
    exit;
}

if ($opt_v) {
    &log("Verbose flag is set ...");
}
	
if ($opt_x) {
    $Debug = $opt_x;	# set debug flag
    undef $opt_x;
    print "\nDebug flag is set ...\n";
} else {
    $Debug = 0;
}

if ($opt_l) {
    $log_file = $opt_l;	# set log path 
    undef $opt_l;
} else {
    $log_file = "areasadm.log";  # in current dir
}

if ($opt_a) {
    $area=$opt_a;   # ? test for a period in echo name (mysql doesn't allow)
		    #so if a period is present it needs to be changed to 
		    #something like an underscore & the bbsname/table name
		    #changed appropriately.  If $opt_e not set, then will
		    #simply remove the period from the name.

    undef $opt_a;
} else {
    $area="TESTECHO";
}

if ($opt_b) {
    $bbsname=$opt_b;
    undef $opt_b;
} else {
    $bbsname=$area;    # bbsname defaults to same as echoname
}

if ($opt_f) {	#  now just defaults to same as echoname
    $desc=$area;    # change this part to pull description from a file
} else {
    $desc=$area;    # description defaults to same as echoname
}

if ($opt_d) {
    $domain=$opt_d;    # setting domain name
} else {
    $domain="";    # domain defaults to blank, which defaults to default
		   # setting of table field, usually 'fidonet'. 
}

if ($opt_t) {
    $type=$opt_t;
} else {
    $type="C";    # defaults to C, i.e. echo/conference
}



# connect to database
#   Assumes that $db_name, $db_user, & $db_password
# have been set.  $db_user must already 
# have the priveledges to create a table.

my $db_name = 'ftndbtst';
my $db_user = 'sysop';
my $db_password = 'ftntstpw';
 
use DBI;

( $db_handle = DBI->connect("dbi:mysql:dbname=$db_name", $db_user, $db_password) )
    or die $DBI::errstr;


## drop the old echo table, if it exists.
##   need a check for if it exists first...
#$sql_statement = "DROP TABLE ";
#$sql_statement .= $bbsname;

##print " $sql_statement \n";
#$db_handle->do( "$sql_statement " );
##    or $drop_ok = "0"; 

# build Create Table sql statement
$sql_statement = "CREATE TABLE ";
$sql_statement .= $bbsname;
$sql_statement .= "( ";

$sql_statement .= "id             INT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY, ";

# ftscdate
$sql_statement .= "ftscdate       VARCHAR(20) DEFAULT '' NOT NULL, ";

# datetime                      
$sql_statement .= "datetime       TIMESTAMP(14) NOT NULL, ";

# fromnode               
$sql_statement .= "fromnode       VARCHAR(72) DEFAULT '' NOT NULL, ";
# tonode                 
$sql_statement .= "tonode         VARCHAR(72) DEFAULT '' NOT NULL, ";

#  fromname              
$sql_statement .= "fromname       VARCHAR(36) DEFAULT '' NOT NULL, ";

#  toname                
$sql_statement .= "toname         VARCHAR(36) DEFAULT '' NOT NULL, ";

#  subject               
$sql_statement .= "subject        VARCHAR(72) DEFAULT '' NOT NULL, ";

#  attributes                    
$sql_statement .= "attrib         SET('Private', 'Crash', 'Recd', 'Sent', ";
$sql_statement .= "'FileAttached', 'InTransit', 'Orphan', 'KillSent', ";
$sql_statement .= "'Local', 'HoldForPickup', 'unused', 'FileRequest', ";
$sql_statement .= "'ReturnREceiptRequest', 'IsReturnReceiptRequest', ";
$sql_statement .= "'AuditRequest', 'FileUpdateReq') DEFAULT '' NOT NULL, ";

#  msgeid                        
$sql_statement .= "msgid          VARCHAR(72) DEFAULT '' NOT NULL, ";

#  replyid                       
$sql_statement .= "replyid        VARCHAR(72) DEFAULT '' NOT NULL, ";

#  body                  
$sql_statement .= "body           MEDIUMBLOB, ";

#  control info                  
$sql_statement .= "ctrlinfo       BLOB, ";

#   table index?
$sql_statement .= "INDEX ";
$sql_statement .= $bbsname;
$sql_statement .= "idx (id, msgid, replyid) ";

$sql_statement .= ") ";

#print " $sql_statement \n";
$db_handle->do( "$sql_statement " ) or die $DBI::errstr;

#
# update areasbbs table
#   add code check if area entry is present first
 $sql_statement = "DELETE FROM areasbbs ";
    $sql_statement .= "WHERE areaname = '$area' ";

#print " $sql_statement \n";
    $db_handle->do( "$sql_statement " );
#        or $insert_ok = "0"; 

    $sql_statement = "INSERT INTO areasbbs ";

    if ($opt_d) {
        $sql_statement .= "(areaname,bbsname,type,domain,description) ";
    } else {
        $sql_statement .= "(areaname,bbsname,type,description) ";
    }
    $sql_statement .= "VALUES (";
#				  need to add the rest?
    $sql_statement .= "'$area', ";
    $sql_statement .= "'$bbsname', ";
    $sql_statement .= "'$type', ";
    if ($opt_d) {
        $sql_statement .= "'$domain', ";
    }
    $sql_statement .= "'$desc') ";

#print " $sql_statement \n";
    $db_handle->do( "$sql_statement " ) or die $DBI::errstr;

#
# disconnect from database

( $db_handle->disconnect )
	or  die $DBI::errstr;

exit();

#############################################
#  logging subrouting.  requires FTN::Log
#############################################
sub log {
#
    my(@text) = @_;
    my $log_id="MTBLE";

    &logging($log_file, $log_id, @text);

}

############################################
# open FTN MySQL database for operations
############################################
sub openftndb {
# Open message database
#   Assumes that $db_name, $db_user, & $db_password
# have been set.  $db_user must already 
# have the priveledges to create a table.

    if ($opt_v) {&log("Opening FTN database")};
	
    my $db_name = 'ftndbtst';
    my $db_user = 'sysop';
    my $db_password = 'ftntstpw';
 
    use DBI;

    ( $db_handle = DBI->connect("dbi:mysql:dbname=$db_name", $db_user, $db_password) )
	or die &log($DBI::errstr);

}

############################################
# Close FTN 
############################################
sub closeftndb {
#
    if ($opt_v) {&logging("Closing FTN database")};

    ( $db_handle->disconnect )
	or die &log($DBI::errstr);
	
}

############################################
